@@ -87,6 +87,7 @@ static void scalix_subscribe_folder (CamelStore *store, const char *folder_name,
 static void scalix_unsubscribe_folder (CamelStore *store, const char *folder_name, CamelException *ex);
 static void scalix_noop (CamelStore *store, CamelException *ex);
 
+static gboolean scalix_can_refresh_folder (CamelStore *store, CamelFolderInfo *info, CamelException *ex);
 
 static CamelFolderInfo *scalix_create_special_folder (CamelStore *store, const char *parent_name, const char *folder_name, guint32 type, CamelException *ex);
 
@@ -163,6 +164,7 @@ camel_scalix_store_class_init (CamelSCALIXStoreClass *klass)
 	store_class->create_folder = scalix_create_folder;
 	store_class->delete_folder = scalix_delete_folder;
 	store_class->rename_folder = scalix_rename_folder;
+	store_class->can_refresh_folder = scalix_can_refresh_folder;
 	store_class->get_folder_info = scalix_get_folder_info;
 	store_class->subscribe_folder = scalix_subscribe_folder;
 	store_class->unsubscribe_folder = scalix_unsubscribe_folder;
@@ -2300,4 +2302,22 @@ change_password (CamelSCALIXStore *store, const char *str, CamelException *ex)
 #endif
 }
 
+static gboolean
+scalix_can_refresh_folder (CamelStore *store, CamelFolderInfo *info, CamelException *ex) 
+{
+	gboolean res; 
+
+	res = CAMEL_STORE_CLASS(parent_class)->can_refresh_folder (store, info, ex) ||
+		(camel_url_get_param (((CamelService *)store)->url, "check_all") != NULL);
+
+	/*if (!res && !camel_exception_is_set (ex)) {
+		CamelFolder *folder;
+
+		folder = camel_store_get_folder (store, info->full_name, 0, ex); 
+		if (folder && CAMEL_IS_IMAP_FOLDER (folder))
+			res = CAMEL_IMAP_FOLDER (folder)->check_folder;
+	}*/
+
+	return res; 
+}
 
